@@ -982,7 +982,7 @@ def output_signal_timing_file_and_modify_microLink_file():
     print("Finished."
           " Thanks for using signal4gmns."
                   " Please use your favorite social media platform to spread the word: https://pypi.org/project/signal4gmns/."
-                  " Please help triage bugs.", 0)
+                  " Please report issues and suggestions at https://github.com/asu-trans-ai-lab/signal4gmns. Thanks！", 0)
 
 
 
